@@ -1,8 +1,11 @@
 import time
 
 class Stopwatch:
-    def __init__(self, flags_limit=10):
+    def __init__(self, flags_limit=10, ticks=1):
+        ''' ticks in seconds '''
+        
         self.time1 = 0
+        self.ticks = ticks
         self.stop_time = 0
         self.start_time_bool = False
         self.start_time = 0
@@ -18,12 +21,12 @@ class Stopwatch:
             if self.start_time:
                 time_now = time.time()
                 self.time1 = time_now - self.start_time
-                return self.time1
+                return self.time1 / self.ticks
             return 0
         else:
             if (self.start_time and self.stop_time):
                 self.time1 = self.stop_time - self.start_time
-                return self.time1
+                return self.time1 / self.ticks
             return 0
         
     def put_flag(self):
